@@ -1,5 +1,5 @@
 from .Table import Table
-from typing import Mapping
+from typing import Iterable, Mapping
 
 class Column :
     """Object for storing a column definition.
@@ -45,6 +45,20 @@ class Column :
             (table, name, function, alias) = cls.parseMap(column)
         return Column(table, name, function, alias)
 
+    @classmethod
+    def createMulti(cls, columns) :
+        """Create multiple Column objects."""
+        columnObjects = ()
+        if isinstance(columns, str) or isinstance(columns, bytes) or isinstance(columns, bytearray) :
+            columnObjects = (cls.create(columns),)
+        elif isinstance(columns, Mapping) :
+            for key in columns.keys() :
+                columnObjects += (Column.create({key: columns[key]}),)
+        elif isinstance(columns, Iterable) :
+            for col in columns :
+                columnObjects += (cls.create(col),)
+        return columnObjects
+
     @classmethod
     def parseStr(cls, column) -> tuple :
         """Parsing string input column to table, column name, and aggregate function."""
