@@ -43,6 +43,15 @@ class Value :
             (columns, values) = cls.parsePair(inputValue)
         return Value(Table.table, columns, values)
 
+    @classmethod
+    def createMulti(cls, inputValues) :
+        """Create multiple Value objects."""
+        valuesObjects = ()
+        if isinstance(inputValues, Iterable) :
+            for val in inputValues :
+                valuesObjects += (Value.create(val),)
+        return valuesObjects
+
     @classmethod
     def parsePair(cls, pairs: Iterable) -> tuple :
         """Parsing column and value pair from input array."""
